@@ -75,6 +75,7 @@ class CohenKappa(Metric):
         >>> cohenkappa(preds, target)
         tensor(0.5000)
     """
+    confmat: Tensor
 
     def __init__(
         self,
@@ -84,8 +85,7 @@ class CohenKappa(Metric):
         compute_on_step: bool = True,
         dist_sync_on_step: bool = False,
         process_group: Optional[Any] = None,
-    ):
-
+    ) -> None:
         super().__init__(
             compute_on_step=compute_on_step,
             dist_sync_on_step=dist_sync_on_step,
@@ -96,12 +96,12 @@ class CohenKappa(Metric):
         self.threshold = threshold
 
         allowed_weights = ('linear', 'quadratic', 'none', None)
-        assert self.weights in allowed_weights, \
-            f"Argument weights needs to one of the following: {allowed_weights}"
+        if self.weights not in allowed_weights:
+            raise ValueError(f"Argument weights needs to one of the following: {allowed_weights}")
 
         self.add_state("confmat", default=torch.zeros(num_classes, num_classes), dist_reduce_fx="sum")
 
-    def update(self, preds: Tensor, target: Tensor):
+    def update(self, preds: Tensor, target: Tensor) -> None:  # type: ignore
         """
         Update state with predictions and targets.
 
@@ -117,3 +117,12 @@ class CohenKappa(Metric):
         Computes cohen kappa score
         """
         return _cohen_kappa_compute(self.confmat, self.weights)
+
+    @property
+    def is_differentiable(self) -> bool:
+        """
+        cohen kappa is not differentiable since the implementation
+        is based on calculating the confusion matrix which in general
+        is not differentiable
+        """
+        return False
