@@ -20,13 +20,13 @@ from torchmetrics.utilities.data import select_topk, to_onehot
 from torchmetrics.utilities.enums import DataType
 
 
-def _check_same_shape(preds: Tensor, target: Tensor):
+def _check_same_shape(preds: Tensor, target: Tensor) -> None:
     """ Check that predictions and target have the same shape, else raise error """
     if preds.shape != target.shape:
         raise RuntimeError("Predictions and targets are expected to have the same shape")
 
 
-def _basic_input_validation(preds: Tensor, target: Tensor, threshold: float, multiclass: bool):
+def _basic_input_validation(preds: Tensor, target: Tensor, threshold: float, multiclass: Optional[bool]) -> None:
     """
     Perform basic validation of inputs that does not require deducing any information
     of the type of inputs.
@@ -44,12 +44,6 @@ def _basic_input_validation(preds: Tensor, target: Tensor, threshold: float, mul
     if not preds.shape[0] == target.shape[0]:
         raise ValueError("The `preds` and `target` should have the same first dimension.")
 
-    if preds_float and (preds.min() < 0 or preds.max() > 1):
-        raise ValueError("The `preds` should be probabilities, but values were detected outside of [0,1] range.")
-
-    if not 0 < threshold < 1:
-        raise ValueError(f"The `threshold` should be a float in the (0,1) interval, got {threshold}")
-
     if multiclass is False and target.max() > 1:
         raise ValueError("If you set `multiclass=False`, then `target` should not exceed 1.")
 
@@ -57,7 +51,7 @@ def _basic_input_validation(preds: Tensor, target: Tensor, threshold: float, mul
         raise ValueError("If you set `multiclass=False` and `preds` are integers, then `preds` should not exceed 1.")
 
 
-def _check_shape_and_type_consistency(preds: Tensor, target: Tensor) -> Tuple[str, int]:
+def _check_shape_and_type_consistency(preds: Tensor, target: Tensor) -> Tuple[DataType, int]:
     """
     This checks that the shape and type of inputs are consistent with
     each other and fall into one of the allowed input types (see the
@@ -119,10 +113,9 @@ def _check_shape_and_type_consistency(preds: Tensor, target: Tensor) -> Tuple[st
     return case, implied_classes
 
 
-def _check_num_classes_binary(num_classes: int, multiclass: bool):
+def _check_num_classes_binary(num_classes: int, multiclass: Optional[bool]) -> None:
     """
-    This checks that the consistency of `num_classes` with the data
-    and `multiclass` param for binary data.
+    This checks that the consistency of `num_classes` with the data and `multiclass` param for binary data.
     """
 
     if num_classes > 2:
@@ -140,7 +133,13 @@ def _check_num_classes_binary(num_classes: int, multiclass: bool):
         )
 
 
-def _check_num_classes_mc(preds: Tensor, target: Tensor, num_classes: int, multiclass: bool, implied_classes: int):
+def _check_num_classes_mc(
+    preds: Tensor,
+    target: Tensor,
+    num_classes: int,
+    multiclass: Optional[bool],
+    implied_classes: int,
+) -> None:
     """
     This checks that the consistency of `num_classes` with the data
     and `multiclass` param for (multi-dimensional) multi-class data.
@@ -153,15 +152,14 @@ def _check_num_classes_mc(preds: Tensor, target: Tensor, num_classes: int, multi
             " to binary/multi-label, set `multiclass=False`."
         )
     if num_classes > 1:
-        if multiclass is False:
-            if implied_classes != num_classes:
-                raise ValueError(
-                    "You have set `multiclass=False`, but the implied number of classes "
-                    " (from shape of inputs) does not match `num_classes`. If you are trying to"
-                    " transform multi-dim multi-class data with 2 classes to multi-label, `num_classes`"
-                    " should be either None or the product of the size of extra dimensions (...)."
-                    " See Input Types in Metrics documentation."
-                )
+        if multiclass is False and implied_classes != num_classes:
+            raise ValueError(
+                "You have set `multiclass=False`, but the implied number of classes "
+                " (from shape of inputs) does not match `num_classes`. If you are trying to"
+                " transform multi-dim multi-class data with 2 classes to multi-label, `num_classes`"
+                " should be either None or the product of the size of extra dimensions (...)."
+                " See Input Types in Metrics documentation."
+            )
         if num_classes <= target.max():
             raise ValueError("The highest label in `target` should be smaller than `num_classes`.")
         if num_classes <= preds.max():
@@ -170,7 +168,7 @@ def _check_num_classes_mc(preds: Tensor, target: Tensor, num_classes: int, multi
             raise ValueError("The size of C dimension of `preds` does not match `num_classes`.")
 
 
-def _check_num_classes_ml(num_classes: int, multiclass: bool, implied_classes: int):
+def _check_num_classes_ml(num_classes: int, multiclass: Optional[bool], implied_classes: int) -> None:
     """
     This checks that the consistency of `num_classes` with the data
     and `multiclass` param for multi-label data.
@@ -186,7 +184,7 @@ def _check_num_classes_ml(num_classes: int, multiclass: bool, implied_classes: i
         raise ValueError("The implied number of classes (from shape of inputs) does not match num_classes.")
 
 
-def _check_top_k(top_k: int, case: str, implied_classes: int, multiclass: Optional[bool], preds_float: bool):
+def _check_top_k(top_k: int, case: str, implied_classes: int, multiclass: Optional[bool], preds_float: bool) -> None:
     if case == DataType.BINARY:
         raise ValueError("You can not use `top_k` parameter with binary data.")
     if not isinstance(top_k, int) or top_k <= 0:
@@ -209,9 +207,9 @@ def _check_classification_inputs(
     target: Tensor,
     threshold: float,
     num_classes: Optional[int],
-    multiclass: bool,
+    multiclass: Optional[bool],
     top_k: Optional[int],
-) -> str:
+) -> DataType:
     """Performs error checking on inputs for classification.
 
     This ensures that preds and target take one of the shape/type combinations that are
@@ -270,11 +268,6 @@ def _check_classification_inputs(
     # Check that shape/types fall into one of the cases
     case, implied_classes = _check_shape_and_type_consistency(preds, target)
 
-    # For (multi-dim) multi-class case with prob preds, check that preds sum up to 1
-    if case in (DataType.MULTICLASS, DataType.MULTIDIM_MULTICLASS) and preds.is_floating_point():
-        if not torch.isclose(preds.sum(dim=1), torch.ones_like(preds.sum(dim=1))).all():
-            raise ValueError("Probabilities in `preds` must sum up to 1 across the `C` dimension.")
-
     # Check consistency with the `C` dimension in case of multi-class data
     if preds.shape != target.shape:
         if multiclass is False and implied_classes != 2:
@@ -323,7 +316,7 @@ def _input_format_classification(
     top_k: Optional[int] = None,
     num_classes: Optional[int] = None,
     multiclass: Optional[bool] = None,
-) -> Tuple[Tensor, Tensor, str]:
+) -> Tuple[Tensor, Tensor, DataType]:
     """Convert preds and target tensors into common format.
 
     Preds and targets are supposed to fall into one of these categories (and are
@@ -439,7 +432,7 @@ def _input_format_classification(
             num_classes = num_classes if num_classes else max(preds.max(), target.max()) + 1
             preds = to_onehot(preds, max(2, num_classes))
 
-        target = to_onehot(target, max(2, num_classes))
+        target = to_onehot(target, max(2, num_classes))  # type: ignore
 
         if multiclass is False:
             preds, target = preds[:, 1, ...], target[:, 1, ...]
@@ -483,7 +476,7 @@ def _input_format_classification_one_hot(
         preds: one hot tensor of shape [num_classes, -1] with predicted labels
         target: one hot tensors of shape [num_classes, -1] with true labels
     """
-    if not (preds.ndim == target.ndim or preds.ndim == target.ndim + 1):
+    if preds.ndim not in (target.ndim, target.ndim + 1):
         raise ValueError("preds and target must have same number of dimensions, or one additional dimension for preds")
 
     if preds.ndim == target.ndim + 1:
