@@ -13,7 +13,6 @@
 # limitations under the License.
 from typing import Any, Callable, List, Mapping, Optional, Sequence, Union
 
-import numpy as np
 import torch
 from torch import Tensor, tensor
 
@@ -22,20 +21,23 @@ from torchmetrics.utilities.prints import rank_zero_warn
 METRIC_EPS = 1e-6
 
 
-def dim_zero_cat(x):
+def dim_zero_cat(x: Union[Tensor, List[Tensor]]) -> Tensor:
     x = x if isinstance(x, (list, tuple)) else [x]
+    x = [y.unsqueeze(0) if y.numel() == 1 and y.ndim == 0 else y for y in x]
+    if not x:  # empty list
+        raise ValueError('No samples to concatenate')
     return torch.cat(x, dim=0)
 
 
-def dim_zero_sum(x):
+def dim_zero_sum(x: Tensor) -> Tensor:
     return torch.sum(x, dim=0)
 
 
-def dim_zero_mean(x):
+def dim_zero_mean(x: Tensor) -> Tensor:
     return torch.mean(x, dim=0)
 
 
-def _flatten(x):
+def _flatten(x: Sequence) -> list:
     return [item for sublist in x for item in sublist]
 
 
@@ -99,12 +101,12 @@ def select_topk(prob_tensor: Tensor, topk: int = 1, dim: int = 1) -> Tensor:
     return topk_tensor.int()
 
 
-def to_categorical(tensor: Tensor, argmax_dim: int = 1) -> Tensor:
+def to_categorical(x: Tensor, argmax_dim: int = 1) -> Tensor:
     """
     Converts a tensor of probabilities to a dense label tensor
 
     Args:
-        tensor: probabilities to get the categorical label [N, d1, d2, ...]
+        x: probabilities to get the categorical label [N, d1, d2, ...]
         argmax_dim: dimension to apply
 
     Return:
@@ -116,7 +118,7 @@ def to_categorical(tensor: Tensor, argmax_dim: int = 1) -> Tensor:
         tensor([1, 0])
 
     """
-    return torch.argmax(tensor, dim=argmax_dim)
+    return torch.argmax(x, dim=argmax_dim)
 
 
 def get_num_classes(
@@ -151,42 +153,13 @@ def get_num_classes(
     return num_classes
 
 
-def _stable_1d_sort(x: torch, nb: int = 2049):
-    """
-    Stable sort of 1d tensors. Pytorch defaults to a stable sorting algorithm
-    if number of elements are larger than 2048. This function pads the tensors,
-    makes the sort and returns the sorted array (with the padding removed)
-    See this discussion: https://discuss.pytorch.org/t/is-torch-sort-stable/20714
-
-    Raises:
-        ValueError:
-            If dim of ``x`` is greater than 1 since stable sort works with only 1d tensors.
-
-    Example:
-        >>> data = torch.tensor([8, 7, 2, 6, 4, 5, 3, 1, 9, 0])
-        >>> _stable_1d_sort(data)
-        (tensor([0, 1, 2, 3, 4, 5, 6, 7, 8, 9]), tensor([9, 7, 2, 6, 4, 5, 3, 1, 0, 8]))
-        >>> _stable_1d_sort(data, nb=5)
-        (tensor([0, 1, 2, 3, 4]), tensor([9, 7, 2, 6, 4]))
-    """
-    if x.ndim > 1:
-        raise ValueError('Stable sort only works on 1d tensors')
-    n = x.numel()
-    if n < nb:
-        x_max = x.max()
-        x = torch.cat([x, (x_max + 1) * torch.ones(nb - n, dtype=x.dtype, device=x.device)], 0)
-    x_sort = x.sort()
-    i = min(nb, n)
-    return x_sort.values[:i], x_sort.indices[:i]
-
-
 def apply_to_collection(
     data: Any,
     dtype: Union[type, tuple],
     function: Callable,
-    *args,
+    *args: Any,
     wrong_dtype: Optional[Union[type, tuple]] = None,
-    **kwargs,
+    **kwargs: Any,
 ) -> Any:
     """
     Recursively applies a function to all elements of a certain dtype.
@@ -231,25 +204,24 @@ def apply_to_collection(
     return data
 
 
-def get_group_indexes(indexes: Union[Tensor, np.ndarray]) -> List[Union[Tensor, np.ndarray]]:
+def get_group_indexes(indexes: Tensor) -> List[Tensor]:
     """
-    Given an integer `torch.Tensor` or `np.ndarray` `indexes`, return a `torch.Tensor` or `np.ndarray` of indexes for
+    Given an integer `torch.Tensor` `indexes`, return a `torch.Tensor` of indexes for
     each different value in `indexes`.
 
     Args:
-        indexes: a `torch.Tensor` or `np.ndarray` of integers
+        indexes: a `torch.Tensor`
 
     Return:
-        A list of integer `torch.Tensor`s or `np.ndarray`s
+        A list of integer `torch.Tensor`s
 
     Example:
         >>> indexes = torch.tensor([0, 0, 0, 1, 1, 1, 1])
         >>> get_group_indexes(indexes)
         [tensor([0, 1, 2]), tensor([3, 4, 5, 6])]
     """
-    structure, dtype = (tensor, torch.long) if isinstance(indexes, Tensor) else (np.array, np.int64)
 
-    res = dict()
+    res: dict = {}
     for i, _id in enumerate(indexes):
         _id = _id.item()
         if _id in res:
@@ -257,4 +229,4 @@ def get_group_indexes(indexes: Union[Tensor, np.ndarray]) -> List[Union[Tensor,
         else:
             res[_id] = [i]
 
-    return [structure(x, dtype=dtype) for x in res.values()]
+    return [tensor(x, dtype=torch.long) for x in res.values()]
