@@ -11,9 +11,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Optional, Union
+from typing import Any, List, Optional
 
 import torch
+import torch.nn.functional as F
 from torch import Tensor
 
 
@@ -75,11 +76,11 @@ def class_reduce(num: Tensor, denom: Tensor, weights: Tensor, class_reduction: s
 
     if class_reduction == "micro":
         return fraction
-    elif class_reduction == "macro":
+    if class_reduction == "macro":
         return torch.mean(fraction)
-    elif class_reduction == "weighted":
+    if class_reduction == "weighted":
         return torch.sum(fraction * (weights.float() / torch.sum(weights)))
-    elif class_reduction == "none" or class_reduction is None:
+    if class_reduction == "none" or class_reduction is None:
         return fraction
 
     raise ValueError(
@@ -88,10 +89,18 @@ def class_reduce(num: Tensor, denom: Tensor, weights: Tensor, class_reduction: s
     )
 
 
-def gather_all_tensors(result: Union[Tensor], group: Optional[Any] = None):
+def _simple_gather_all_tensors(result: Tensor, group: Any, world_size: int) -> List[Tensor]:
+    gathered_result = [torch.zeros_like(result) for _ in range(world_size)]
+    torch.distributed.all_gather(gathered_result, result, group)
+    return gathered_result
+
+
+def gather_all_tensors(result: Tensor, group: Optional[Any] = None) -> List[Tensor]:
     """
     Function to gather all tensors from several ddp processes onto a list that
-    is broadcasted to all processes
+    is broadcasted to all processes. Works on tensors that have the same number
+    of dimensions, but where each dimension may differ. In this case tensors are
+    padded, gathered and then trimmed to secure equal workload for all processes
 
     Args:
         result: the value to sync
@@ -108,11 +117,33 @@ def gather_all_tensors(result: Union[Tensor], group: Optional[Any] = None):
     result = result.contiguous()
 
     world_size = torch.distributed.get_world_size(group)
-
-    gathered_result = [torch.zeros_like(result) for _ in range(world_size)]
-
-    # sync and broadcast all
     torch.distributed.barrier(group=group)
-    torch.distributed.all_gather(gathered_result, result, group)
 
+    # if the tensor is scalar, things are easy
+    if result.ndim == 0:
+        return _simple_gather_all_tensors(result, group, world_size)
+
+    # 1. Gather sizes of all tensors
+    local_size = torch.tensor(result.shape, device=result.device)
+    local_sizes = [torch.zeros_like(local_size) for _ in range(world_size)]
+    torch.distributed.all_gather(local_sizes, local_size, group=group)
+    max_size = torch.stack(local_sizes).max(dim=0).values
+    all_sizes_equal = all(all(ls == max_size) for ls in local_sizes)
+
+    # 2. If shapes are all the same, then do a simple gather:
+    if all_sizes_equal:
+        return _simple_gather_all_tensors(result, group, world_size)
+
+    # 3. If not, we need to pad each local tensor to maximum size, gather and then truncate
+    pad_dims = []
+    pad_by = (max_size - local_size).detach().cpu()
+    for val in reversed(pad_by):
+        pad_dims.append(0)
+        pad_dims.append(val.item())
+    result_padded = F.pad(result, pad_dims)
+    gathered_result = [torch.zeros_like(result_padded) for _ in range(world_size)]
+    torch.distributed.all_gather(gathered_result, result_padded, group)
+    for idx, item_size in enumerate(local_sizes):
+        slice_param = [slice(dim_size) for dim_size in item_size]
+        gathered_result[idx] = gathered_result[idx][slice_param]
     return gathered_result
