@@ -15,7 +15,7 @@
 import operator
 from importlib import import_module
 from importlib.util import find_spec
-from typing import Optional
+from typing import Callable, Optional
 
 from packaging.version import Version
 from pkg_resources import DistributionNotFound, get_distribution
@@ -40,7 +40,7 @@ def _module_available(module_path: str) -> bool:
         return False
 
 
-def _compare_version(package: str, op, version) -> Optional[bool]:
+def _compare_version(package: str, op: Callable, version: str) -> Optional[bool]:
     """
     Compare package version with some requirements
 
@@ -53,7 +53,7 @@ def _compare_version(package: str, op, version) -> Optional[bool]:
         return None
     try:
         pkg = import_module(package)
-        pkg_version = pkg.__version__
+        pkg_version = pkg.__version__  # type: ignore
     except (ModuleNotFoundError, DistributionNotFound):
         return None
     except ImportError:
@@ -68,9 +68,11 @@ def _compare_version(package: str, op, version) -> Optional[bool]:
     return op(pkg_version, Version(version))
 
 
-_TORCH_LOWER_1_4 = _compare_version("torch", operator.lt, "1.4.0")
-_TORCH_LOWER_1_5 = _compare_version("torch", operator.lt, "1.5.0")
-_TORCH_LOWER_1_6 = _compare_version("torch", operator.lt, "1.6.0")
-_TORCH_GREATER_EQUAL_1_6 = _compare_version("torch", operator.ge, "1.6.0")
-_TORCH_GREATER_EQUAL_1_7 = _compare_version("torch", operator.ge, "1.7.0")
-_LIGHTNING_AVAILABLE = _module_available("pytorch_lightning")
+_TORCH_LOWER_1_4: Optional[bool] = _compare_version("torch", operator.lt, "1.4.0")
+_TORCH_LOWER_1_5: Optional[bool] = _compare_version("torch", operator.lt, "1.5.0")
+_TORCH_LOWER_1_6: Optional[bool] = _compare_version("torch", operator.lt, "1.6.0")
+_TORCH_GREATER_EQUAL_1_6: Optional[bool] = _compare_version("torch", operator.ge, "1.6.0")
+_TORCH_GREATER_EQUAL_1_7: Optional[bool] = _compare_version("torch", operator.ge, "1.7.0")
+_LIGHTNING_AVAILABLE: bool = _module_available("pytorch_lightning")
+_TORCH_FIDELITY_AVAILABLE: bool = _module_available("torch_fidelity")
+_SCIPY_AVAILABLE: bool = _module_available("scipy")
